Catalog Manages a pool of actors, exposes an API define_actor() for instantiating actors in the system. Provides internal apis for activatation/restoration of actors, a handle to backend store.

Structs

Maintains a pool of actors, a handle to the backing store, exposes an API for defining(registering) new actor Producer.

Functions

Define an actor in the system providing the actor address(Addr) and an implmentation of Producer. Existing actor with the same address, if any, would be removed and a pre-shutdown signal would be sent to the removed instance. New actor would be added to a pool of in memory actors and it would receive a startup signal. Supplied producer definition would be peristed in the backing store. On restart - actors will be restored on demand to process pending or incoming messages. Actors will restart from where they left off.