pub struct Config { /* private fields */ }Expand description
The config struct
Implementations
Sourceimpl Config
impl Config
Get the read lock
Sourcepub fn resident_listener(&self) -> &str
pub fn resident_listener(&self) -> &str
Location of listener binary
Sourcepub fn set_host(&mut self, host: &str)
pub fn set_host(&mut self, host: &str)
Gets reinitialzed based on user supplied IP:PORT - Addrs get created based on this
Sourcepub fn set_db_path(&mut self, db_path: &str)
pub fn set_db_path(&mut self, db_path: &str)
Alter it if running multiple arrows instances on the same node
Sourcepub fn set_resident_listener(&mut self, resident_listener: &str)
pub fn set_resident_listener(&mut self, resident_listener: &str)
Depends on what profile we are running under. Final location of the listener binary.
Sourcepub fn db_buff_size(&self) -> usize
pub fn db_buff_size(&self) -> usize
How much buffering the backing store should instead of executing database operations for every transaction that takes place in the system.
Configurable via db_buffer_size.
Sourcepub fn set_db_buff_size(&mut self, buff_size: usize)
pub fn set_db_buff_size(&mut self, buff_size: usize)
Set the db_buff_size. It should update all cached values. Currently its loaded at system start time