pub enum Error {
Registration(Error),
MsgSendError(Error),
SerdeJson(Error),
Other(Box<dyn Error>),
InvalidData,
RegistrationError,
RestorationError,
Bincode(ErrorKind),
}Expand description
#Error Various error messages during the arrows execution path.
Variants
Registration(Error)
IO erros during registration
MsgSendError(Error)
Error while sending and receiving messages
SerdeJson(Error)
Errors related serde serialization and deserialization
Other(Box<dyn Error>)
Akin to unknown error
InvalidData
Invalid payload etc
RegistrationError
Registration error not due to IO
RestorationError
Error that might happen during actor activation from the backing store
Bincode(ErrorKind)
Most of the tings gets stored as binary blobs and system depends heavily depends on bincode - this variant captures errors related bincode