This module handles method invocation on actors. Maintains a number of Delegates equal to the number of cpus in the running nodes.

The Router is responsible for handing out messages to the delegates which shares a Receiver queue.

Modules

Ingress happens via the MessegeListener struct defined in this module The listener binary can can be manually triggered via cargo run --bin arrows.

Messenger sends out messages to remote or local system. Tries to boot up listener binary in case of local connection failre.