Struct arrows::Addr

source · []
pub struct Addr { /* private fields */ }
Unique actor addresses based on IP, PORT and names. Some fields are later extension points

Implementations

A new local actor address - bound to be unique. Actors with same name will have different ids based on system ports even if multiple instances of the arrows systems are running on the same node

An actor running on a different local or remote system

Alter the port - to talk to different system

Alter the IP - as requried

Human readable name of an actor

Internally used by the system for unique address identification

Address host ip

Needed for support remoting - used to decide if listener should be booted if not already up if message comes in

Mostly for routing decisions

Routing

Is the local - based on port or ip or both together

Handle to host

Handle to port

For serialization

The address of the listener