pub struct Addr { /* private fields */ }Expand description
Unique actor addresses based on IP, PORT and names. Some fields are later extension points
Implementations
A new local actor address - bound to be unique. Actors with same name will have different ids based on system ports even if multiple instances of the arrows systems are running on the same node
An actor running on a different local or remote system
Address host ip
Needed for support remoting - used to decide if listener should be booted if not already up if message comes in
Mostly for routing decisions
Routing
The address of the listener